Module lru

Module lru 

Least recently used (LRU) replacement policy implementation and traits for working with LRU timestamps.

Structs

LruReplacement
Least recently used (LRU) cache replacement.
WithLruTimestamp
A wrapper around a T cache value that maintains a timestamp for use with LRU cache replacement policies.

Traits

LruTimestamp
A trait for anything that has a timestamp that we can use with an LRU cache replacement policy.