WithLruTimestamp

Struct WithLruTimestamp 

pub struct WithLruTimestamp<T> { /* private fields */ }
A wrapper around a T cache value that maintains a timestamp for use with LRU cache replacement policies.

Provides Deref[Mut] and As{Ref,Mut} implementations, so it is easy to drop in with minimal source changes.

You can recover ownership of the inner T value via WithLruTimestamp::into_inner(x) once a value has been removed from the cache.

Example

use associative_cache::*;

let cache = AssociativeCache::<
    String,
    // Wrap your cache value in `WithLruTimestamp`...
    WithLruTimestamp<usize>,
    Capacity128,
    HashEightWay,
    // ... and take advantage of LRU cache replacement!
    LruReplacement,
>::default();

Implementations

Source

impl<T> WithLruTimestamp<T>

pub fn new(inner: T) -> WithLruTimestamp<T>

Construct a new WithLruTimestamp wrapper around an inner value.

Example
use associative_cache::*;

let inner = "hello!".to_string();
let outer = WithLruTimestamp::new(inner);
pub fn into_inner(outer: WithLruTimestamp<T>) -> T

Recover the inner T value by consuming a WithLruTimestamp<T>.

Example
use associative_cache::*;

let outer = WithLruTimestamp::new("hello!".to_string());
let inner = WithLruTimestamp::into_inner(outer);
assert_eq!(inner, "hello!");